@@ -11,7 +11,6 @@
 #include "progressbar.h"
 
 #include <libkleo/defaultkeyfilter.h>
-#include <libkleo/dn.h>
 #include <libkleo/formatting.h>
 #include <libkleo/keycache.h>
 #include <libkleo/keylist.h>
@@ -22,6 +21,8 @@
 
 #include <KLocalizedString>
 
+#include <QGpgME/DN>
+
 #include <QAbstractProxyModel>
 #include <QList>
 #include <QSortFilterProxyModel>
@@ -80,7 +81,7 @@ static QString formatUserID(const GpgME::Key &key)
         name = QString::fromUtf8(userID.name());
         email = QString::fromUtf8(userID.email());
     } else {
-        const Kleo::DN dn(userID.id());
+        const QGpgME::DN dn(userID.id());
         name = dn[QStringLiteral("CN")];
         email = dn[QStringLiteral("EMAIL")];
     }
@@ -92,7 +93,7 @@ class SortAndFormatCertificatesProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 
 public:
-    SortAndFormatCertificatesProxyModel(KeyUsage::Flags usageFlags, QObject *parent = nullptr)
+    explicit SortAndFormatCertificatesProxyModel(KeyUsage::Flags usageFlags, QObject *parent = nullptr)
         : QSortFilterProxyModel{parent}
         , mIconProvider{usageFlags}
     {
@@ -172,21 +173,7 @@ protected:
         switch (role) {
         case Qt::DisplayRole:
         case Qt::AccessibleTextRole: {
-            const auto nameAndEmail = formatUserID(key);
-            if (Kleo::KeyCache::instance()->pgpOnly()) {
-                return i18nc("Name <email> (validity, created: date)",
-                             "%1 (%2, created: %3)",
-                             nameAndEmail,
-                             Kleo::Formatting::complianceStringShort(key),
-                             Kleo::Formatting::creationDateString(key));
-            } else {
-                return i18nc("Name <email> (validity, type, created: date)",
-                             "%1 (%2, %3, created: %4)",
-                             nameAndEmail,
-                             Kleo::Formatting::complianceStringShort(key),
-                             Formatting::displayName(key.protocol()),
-                             Kleo::Formatting::creationDateString(key));
-            }
+            return Formatting::summaryLine(key);
         }
         case Qt::ToolTipRole: {
             using namespace Kleo::Formatting;
@@ -217,7 +204,7 @@ private:
     };
 
 public:
-    CustomItemsProxyModel(QObject *parent = nullptr)
+    explicit CustomItemsProxyModel(QObject *parent = nullptr)
         : QAbstractProxyModel(parent)
     {
     }
