@@ -103,7 +103,7 @@ template<typename T>
 class asKeyValueRange
 {
 public:
-    asKeyValueRange(T &data)
+    explicit asKeyValueRange(T &data)
         : m_data{data}
     {
     }
@@ -154,7 +154,8 @@ static bool isMailFile(const QFileInfo &fi)
     {
         Kleo::ClassifyConfig classifyConfig;
 
-        if (classifyConfig.p7mWithoutExtensionAreEmail() && fileName.endsWith(QStringLiteral(".p7m")) && fi.completeSuffix() == fi.suffix()) {
+        if (classifyConfig.p7mWithoutExtensionAreEmail() && fileName.endsWith(QStringLiteral(".p7m"), Qt::CaseInsensitive)
+            && fi.completeSuffix() == fi.suffix()) {
             // match "myfile.p7m" but not "myfile.pdf.p7m"
             return true;
         }
@@ -167,7 +168,7 @@ static bool isMailFile(const QFileInfo &fi)
 
 static unsigned int classifyExtension(const QFileInfo &fi)
 {
-    return classifications.value(fi.suffix(), defaultClassification);
+    return classifications.value(fi.suffix().toLower(), defaultClassification);
 }
 
 unsigned int Kleo::classify(const QString &filename)
@@ -304,7 +305,7 @@ static QString stripOutlookAttachmentNumbering(const QString &s)
 QString Kleo::outputFileName(const QString &inputFileName)
 {
     const QFileInfo fi(inputFileName);
-    const QString suffix = fi.suffix();
+    const QString suffix = fi.suffix().toLower();
 
     if (classifications.find(suffix) == std::cend(classifications)) {
         return inputFileName + QLatin1StringView(".out");
